############################################################
# FlatCAM: 2D Post-processing for Manufacturing            #
# http://flatcam.org                                       #
# Author: Damian Wrobel <dwrobel@ertelnet.rybnik.pl>       #
# Date: 05/23/2017                                         #
# MIT Licence                                              #
# A setuptools based setup module                          #
############################################################

from setuptools import setup
import glob

setup(
    name='FlatCAM',

    version='8.5',

    description='2D Computer-Aided PCB Manufacturing',

    long_description=('FlatCAM is a program for preparing CNC jobs for making'
                      'PCBs on a CNC router. Among other things, it can take'
                      'a Gerber file generated by your favorite PCB CAD'
                      'program, and create G-Code for Isolation routing.'),

    url='http://flatcam.org/',

    author='Juan Pablo Caram',

    license='MIT',

    packages=[
        'descartes',
        'tclCommands'
    ],

    py_modules=[
        "camlib",
        "DblSidedTool",
        "FlatCAMApp",
        "FlatCAMCommon",
        "FlatCAMDraw",
        "FlatCAMGUI",
        "FlatCAMObj",
        "FlatCAMProcess",
        "FlatCAMShell",
        "FlatCAMTool",
        "FlatCAMVersion",
        "FlatCAMWorker",
        "GUIElements",
        "MeasurementTool",
        "ObjectCollection",
        "ObjectUI",
        "PlotCanvas",
        "svgparse",
        "termwidget"
    ],

    install_requires=[
        'simplejson',
        'numpy>=1.8',
        'scipy',
        'matplotlib>=1.3.1',
        'shapely>=1.3'
        'rtree',
        'svg.path'
    ],

    include_package_data=True,

    data_files=[
        ('share/flatcam', glob.glob('share/*'))
    ],

    scripts=['flatcam']
)
